@@ -14,22 +14,28 @@ INST = docx2python("resources/example.docx")
 class TestDocument:
     def test_combine_of_header_body_footer(self) -> None:
         """Return all content combined as instance.document """
-        assert INST.document == INST.header + INST.body + INST.footer
+        assert (
+            INST.document
+            == INST.header + INST.body + INST.footer + INST.footnotes + INST.endnotes
+        )
 
     def test_read_only(self) -> None:
         """Document attribute is read only."""
         doc1 = INST.document
         doc1 = doc1[:1]
         assert doc1 != INST.document
-        assert INST.document == INST.header + INST.body + INST.footer
+        assert (
+            INST.document
+            == INST.header + INST.body + INST.footer + INST.footnotes + INST.endnotes
+        )
 
 
 class TestText:
     def test_function(self) -> None:
         """Return '\n\n'-delimited paragraphs as instance.text. """
         assert INST.text[:50] == (
-            "Header text\n\nI)	expect I\n" "\n	A)	expect A\n\n	B)	expect"
+            "\n\n\n\nHeader text----media/image1.png----\n\nI)	expect"
         )
         assert INST.text[-50:] == (
-            "\nText outside table----image1.jpg----\n\nFooter text"
+            "ndnote2)	\n\n Second endnote----media/image1.png----"
         )
